@@ -64,11 +64,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) : QDialog(parent)
     connect(m_removeButton, &QPushButton::clicked, this, &SettingsDialog::removeFolder);
     connect(resetButton, &QPushButton::clicked, this, &SettingsDialog::reset);
     connect(closeButton, &QPushButton::clicked, this, &SettingsDialog::close);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_schemaGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), this, &SettingsDialog::changeScheme);
-#else
-    connect(m_schemaGroup, &QButtonGroup::buttonClicked, this, &SettingsDialog::changeScheme);
-#endif
 
     connect(contrastSlider, &QSlider::valueChanged, this, &SettingsDialog::changeContrast);
     connect(contrastSlider, &QSlider::sliderReleased, this, &SettingsDialog::slotSliderReleased);
